pub struct ComponentRegistry { /* private fields */ }Expand description
A registry of CustomNodeFactoryes used by the layout builder.
Implementations
Sourceimpl ComponentRegistry
impl ComponentRegistry
Sourcepub fn register(&mut self, factory: Box<dyn CustomNodeFactory>)
pub fn register(&mut self, factory: Box<dyn CustomNodeFactory>)
Registers a factory, replacing any factory with the same tags.
All tags the registry can construct.
Sourcepub fn create(&self, ctx: &CustomNodeContext<'_>) -> Option<Arc<dyn CustomNode>>
pub fn create(&self, ctx: &CustomNodeContext<'_>) -> Option<Arc<dyn CustomNode>>
Constructs a node for tag, or None if no factory handles it.